@@ -6,7 +6,7 @@
  *
  * Copyright (c) 1994, Regents of the University of California
  *
- * $Id: sdir.h,v 1.2 1995/02/12 22:25:11 andrew Exp $
+ * $Id: sdir.h,v 1.2 1996/07/30 07:44:57 scrappy Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -27,7 +27,7 @@ typedef enum ScanDirection {
 
 /*
  * ScanDirectionIsValid --
- *	True iff scan direciton is valid.
+ *	True iff scan direction is valid.
  */
 #define ScanDirectionIsValid(direction) \
     ((bool) (BackwardScanDirection <= direction && \
@@ -35,21 +35,21 @@ typedef enum ScanDirection {
 
 /*
  * ScanDirectionIsBackward --
- *	True iff scan direciton is backward.
+ *	True iff scan direction is backward.
  */
 #define ScanDirectionIsBackward(direction) \
     ((bool) (direction == BackwardScanDirection))
 
 /*
  * ScanDirectionIsNoMovement --
- *	True iff scan direciton indicates no movement.
+ *	True iff scan direction indicates no movement.
  */
 #define ScanDirectionIsNoMovement(direction) \
     ((bool) (direction == NoMovementScanDirection))
 
 /*
  * ScanDirectionIsForward --
- *	True iff scan direciton is forward.
+ *	True iff scan direction is forward.
  */
 #define ScanDirectionIsForward(direction) \
     ((bool) (direction == ForwardScanDirection))
