@@ -7,7 +7,7 @@
  *
  *
  * IDENTIFICATION
- *    $Header: /usr/local/devel/pglite/cvs/src/bin/pg_version/pg_version.c,v 1.1.1.1 1994/11/07 05:20:11 andrew Exp $
+ *    $Header: /usr/local/cvsroot/postgres95/src/bin/pg_version/pg_version.c,v 1.2 1996/07/31 02:19:23 scrappy Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -31,5 +31,5 @@ elog() {}
 
 GetDataHome()
 {
-	return(NULL);
+	return(0);
 }
